summaryrefslogtreecommitdiff
path: root/xmloff/inc/txtvfldi.hxx
diff options
context:
space:
mode:
authorNoel <noelgrandin@gmail.com>2020-11-02 12:26:26 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2020-11-02 17:08:47 +0100
commit3940cf7d716f3e469f47d3c831a799e58edf2eb8 (patch)
tree96c54b88e76e8eeff2b58700fce6a3b4f6722cde /xmloff/inc/txtvfldi.hxx
parentdd24e21bb4f183048a738314934fc3f02ec093f1 (diff)
drop the SvXMLExport::EndElement method..
in favour of just using the endFastElement() method Change-Id: Id95abb0b9e78bc44278c5e9e3cc8dee15185e2e2 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/105175 Tested-by: Jenkins Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'xmloff/inc/txtvfldi.hxx')
-rw-r--r--xmloff/inc/txtvfldi.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/xmloff/inc/txtvfldi.hxx b/xmloff/inc/txtvfldi.hxx
index d399ff2beea9..2ad378a9e670 100644
--- a/xmloff/inc/txtvfldi.hxx
+++ b/xmloff/inc/txtvfldi.hxx
@@ -243,7 +243,7 @@ public:
const char* pServiceName, /// see XMLTextFieldImportContext
sal_uInt16 nPrfx, /// see XMLTextFieldImportContext
const OUString& rLocalName, /// see XMLTextFieldImportContext
// for finding appropriate field master (see EndElement())
VarType eVarType, /// variable type
// config variables:
bool bFormula, /// see XMLTextFieldImportContext
@@ -262,7 +262,7 @@ protected:
/// create XTextField, attach master and insert into document;
/// also calls PrepareTextField
- virtual void EndElement() override;
+ virtual void SAL_CALL endFastElement(sal_Int32 nElement) override;
/// find appropriate field master
bool FindFieldMaster(
@@ -476,7 +476,7 @@ private:
const OUString& sAttrValue ) override;
/// create, prepare and insert database field master and database field
- virtual void EndElement() override;
+ virtual void SAL_CALL endFastElement(sal_Int32 nElement) override;
};
#endif
@@ -243,7 +243,7 @@ public:
sal_uInt16 nPrfx, /// see XMLTextFieldImportContext
const OUString& rLocalName, /// see XMLTextFieldImportContext
- // for finding appropriate field master (see EndElement())
+ // for finding appropriate field master (see endFastElement())
VarType eVarType, /// variable type
// config variables: